==> huaweicloudsdkvod-3.1.131-py2.py3-none-any.whl: huaweicloudsdkvod/v1/model/list_asset_daily_summary_log_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListAssetDailySummaryLogResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'summary_results': 'list[AssetDailySummaryResult]'
    }

    attribute_map = {
        'total': 'total',
        'summary_results': 'summary_results'
    }

    def __init__(self, total=None, summary_results=None):
        """ListAssetDailySummaryLogResponse

        The model defined in huaweicloud sdk

        :param total: 记录总数 
        :type total: int
        :param summary_results: 日志文件列表 
        :type summary_results: list[:class:`huaweicloudsdkvod.v1.AssetDailySummaryResult`]
        """
        
        super(ListAssetDailySummaryLogResponse, self).__init__()

        self._total = None
        self._summary_results = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if summary_results is not None:
            self.summary_results = summary_results

    @property
    def total(self):
        """Gets the total of this ListAssetDailySummaryLogResponse.

        记录总数 

        :return: The total of this ListAssetDailySummaryLogResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListAssetDailySummaryLogResponse.

        记录总数 

        :param total: The total of this ListAssetDailySummaryLogResponse.
        :type total: int
        """
        self._total = total

    @property
    def summary_results(self):
        """Gets the summary_results of this ListAssetDailySummaryLogResponse.

        日志文件列表 

        :return: The summary_results of this ListAssetDailySummaryLogResponse.
        :rtype: list[:class:`huaweicloudsdkvod.v1.AssetDailySummaryResult`]
        """
        return self._summary_results

    @summary_results.setter
    def summary_results(self, summary_results):
        """Sets the summary_results of this ListAssetDailySummaryLogResponse.

        日志文件列表 

        :param summary_results: The summary_results of this ListAssetDailySummaryLogResponse.
        :type summary_results: list[:class:`huaweicloudsdkvod.v1.AssetDailySummaryResult`]
        """
        self._summary_results = summary_results

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListAssetDailySummaryLogResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvod-3.1.147-py2.py3-none-any.whl: huaweicloudsdkvod/v1/model/list_asset_daily_summary_log_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListAssetDailySummaryLogResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'summary_results': 'list[AssetDailySummaryResult]'
    }

    attribute_map = {
        'total': 'total',
        'summary_results': 'summary_results'
    }

    def __init__(self, total=None, summary_results=None):
        r"""ListAssetDailySummaryLogResponse

        The model defined in huaweicloud sdk

        :param total: 记录总数 
        :type total: int
        :param summary_results: 日志文件列表 
        :type summary_results: list[:class:`huaweicloudsdkvod.v1.AssetDailySummaryResult`]
        """
        
        super(ListAssetDailySummaryLogResponse, self).__init__()

        self._total = None
        self._summary_results = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if summary_results is not None:
            self.summary_results = summary_results

    @property
    def total(self):
        r"""Gets the total of this ListAssetDailySummaryLogResponse.

        记录总数 

        :return: The total of this ListAssetDailySummaryLogResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        r"""Sets the total of this ListAssetDailySummaryLogResponse.

        记录总数 

        :param total: The total of this ListAssetDailySummaryLogResponse.
        :type total: int
        """
        self._total = total

    @property
    def summary_results(self):
        r"""Gets the summary_results of this ListAssetDailySummaryLogResponse.

        日志文件列表 

        :return: The summary_results of this ListAssetDailySummaryLogResponse.
        :rtype: list[:class:`huaweicloudsdkvod.v1.AssetDailySummaryResult`]
        """
        return self._summary_results

    @summary_results.setter
    def summary_results(self, summary_results):
        r"""Sets the summary_results of this ListAssetDailySummaryLogResponse.

        日志文件列表 

        :param summary_results: The summary_results of this ListAssetDailySummaryLogResponse.
        :type summary_results: list[:class:`huaweicloudsdkvod.v1.AssetDailySummaryResult`]
        """
        self._summary_results = summary_results

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListAssetDailySummaryLogResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
